==> windmill_api-1.564.0.tar.gz: windmill_api-1.564.0/windmill_api/models/delete_completed_job_response_200_raw_flow_failure_module_timeout_type_0.py <==
from typing import Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.delete_completed_job_response_200_raw_flow_failure_module_timeout_type_0_type import (
    DeleteCompletedJobResponse200RawFlowFailureModuleTimeoutType0Type,
)

T = TypeVar("T", bound="DeleteCompletedJobResponse200RawFlowFailureModuleTimeoutType0")


@_attrs_define
class DeleteCompletedJobResponse200RawFlowFailureModuleTimeoutType0:
    """
    Attributes:
        value (Any):
        type (DeleteCompletedJobResponse200RawFlowFailureModuleTimeoutType0Type):
    """

    value: Any
    type: DeleteCompletedJobResponse200RawFlowFailureModuleTimeoutType0Type
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        value = self.value
        type = self.type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "value": value,
                "type": type,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        value = d.pop("value")

        type = DeleteCompletedJobResponse200RawFlowFailureModuleTimeoutType0Type(d.pop("type"))

        delete_completed_job_response_200_raw_flow_failure_module_timeout_type_0 = cls(
            value=value,
            type=type,
        )

        delete_completed_job_response_200_raw_flow_failure_module_timeout_type_0.additional_properties = d
        return delete_completed_job_response_200_raw_flow_failure_module_timeout_type_0

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> windmill_api-1.575.2.tar.gz: windmill_api-1.575.2/windmill_api/models/delete_completed_job_response_200_raw_flow_failure_module_timeout_type_0.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.delete_completed_job_response_200_raw_flow_failure_module_timeout_type_0_type import (
    DeleteCompletedJobResponse200RawFlowFailureModuleTimeoutType0Type,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="DeleteCompletedJobResponse200RawFlowFailureModuleTimeoutType0")


@_attrs_define
class DeleteCompletedJobResponse200RawFlowFailureModuleTimeoutType0:
    """
    Attributes:
        type (DeleteCompletedJobResponse200RawFlowFailureModuleTimeoutType0Type):
        value (Union[Unset, Any]):
    """

    type: DeleteCompletedJobResponse200RawFlowFailureModuleTimeoutType0Type
    value: Union[Unset, Any] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type.value

        value = self.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
            }
        )
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = DeleteCompletedJobResponse200RawFlowFailureModuleTimeoutType0Type(d.pop("type"))

        value = d.pop("value", UNSET)

        delete_completed_job_response_200_raw_flow_failure_module_timeout_type_0 = cls(
            type=type,
            value=value,
        )

        delete_completed_job_response_200_raw_flow_failure_module_timeout_type_0.additional_properties = d
        return delete_completed_job_response_200_raw_flow_failure_module_timeout_type_0

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
